pub struct RandomProjectionCodec {
pub seed: u64,
pub reduction: RandomProjectionReduction,
pub projection: RandomProjectionKind,
pub version: StaticCodecVersion<0, 1, 0>,
}Expand description
Codec that uses random projections to reduce the dimensionality of high- dimensional data to compress it.
A two-dimensional array of shape $N \times D$ is encoded as n array of
shape $N \times K$, where $K$ is either set explicitly or chosen using
the the Johnson-Lindenstrauss lemma. For $K$ to be smaller than $D$,
$D$ must be quite large. Therefore, this codec should only applied on
large datasets as it otherwise significantly inflates the data size instead
of reducing it.
Choosing a lower distortion rate epsilon will improve the quality of the
lossy compression, i.e. reduce the compression error, at the cost of
increasing $K$.
This codec only supports finite floating point data.
Fields
seed: u64Seed for generating the random projection matrix
reduction: RandomProjectionReductionMethod with which the reduced dimensionality $K$ is selected
projection: RandomProjectionKindProjection kind that is used to generate the random projection matrix
version: StaticCodecVersion<0, 1, 0>The codec’s encoding format version. Do not provide this parameter explicitly.